@@ -1,22 +1,11 @@
-#
-# This file is part of Dist-Zilla-Plugin-OSPrereqs
-#
-# This software is Copyright (c) 2011 by David Golden.
-#
-# This is free software, licensed under:
-#
-#   The Apache License, Version 2.0, January 2004
-#
 use 5.008001;
 use strict;
 use warnings;
 use utf8;
 
 package Dist::Zilla::Plugin::OSPrereqs;
-BEGIN {
-  $Dist::Zilla::Plugin::OSPrereqs::VERSION = '0.002';
-}
 # ABSTRACT: List prereqs conditional on operating system
+our $VERSION = '0.003'; # VERSION
 
 use Moose;
 use List::AllUtils 'first';
@@ -54,6 +43,30 @@ has _prereq => (
   default => sub { {} },
 );
 
+has _builder => (
+  is   => 'rw',
+  isa  => 'Str',
+  default => 'makemaker',
+);
+
+has _prereq_str => (
+  is   => 'ro',
+  isa  => 'HashRef',
+  default => sub { {
+      makemaker   => "\t\$WriteMakefileArgs{PREREQ_PM}",
+      modulebuild => "\t\$module_build_args{requires}",
+  } },
+);
+
+has _builder_regex => (
+  is   => 'ro',
+  isa  => 'HashRef',
+  default => sub { {
+      makemaker   => 'WriteMakefile\s*\(',
+      modulebuild => 'my \$build',
+  } },
+);
+
 sub BUILDARGS {
   my ($class, @arg) = @_;
   my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
@@ -80,29 +93,36 @@ sub BUILDARGS {
   }
 }
 
-
 sub setup_installer {
   my ($self) = @_;
   return unless my $os = $self->prereq_os;
 
-  my $makefile = first { $_->name eq 'Makefile.PL' } @{ $self->zilla->files };
-  $self->log_fatal('No Makefile.PL. It needs to be provided by another plugin')
-    unless $makefile;
+  # first, try MakeMaker
+  my $build_script = first { $_->name eq 'Makefile.PL' } @{ $self->zilla->files };
+  if (!$build_script) {
+    $build_script = first { $_->name eq 'Build.PL' } @{ $self->zilla->files };
+    if ($build_script) {
+      $self->_builder('modulebuild');
+    } else {
+      $self->log_fatal('No Build.PL or Makefile.PL found. Using either [MakeMaker] or [ModuleBuild] is required');
+    }
+  }
 
-  my $content = $makefile->content;
+  my $content = $build_script->content;
 
   my $prereq_str = "if ( \$^O eq '$os' ) {\n";
   my $prereq_hash = $self->_prereq;
   for my $k ( sort keys %$prereq_hash ) {
     my $v = $prereq_hash->{$k};
-    $prereq_str .= "  \$WriteMakefileArgs{PREREQ_PM}{'$k'} = '$v';\n";
+    $prereq_str .= $self->_prereq_str->{$self->_builder} . "{'$k'} = '$v';\n";
   }
   $prereq_str .= "}\n\n";
 
-  $content =~ s/(?=WriteMakefile\s*\()/$prereq_str/
+  my $reg = $self->_builder_regex->{$self->_builder};
+  $content =~ s/(?=$reg)/$prereq_str/
     or $self->log_fatal("Failed to insert conditional prereq for $os");
 
-  $makefile->content($content);
+  return $build_script->content($content);
 }
 
 sub metadata {
@@ -113,7 +133,7 @@ no Moose;
 __PACKAGE__->meta->make_immutable(inline_constructor => 1);
 1;
 
-
+__END__
 
 =pod
 
@@ -123,7 +143,7 @@ Dist::Zilla::Plugin::OSPrereqs - List prereqs conditional on operating system
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -143,13 +163,32 @@ C<<< PREREQ_PM >>> in the Makefile.PL
 
 =head1 WARNING
 
-This plugin only works for Makefile.PL geneated by the
-L<Dist::Zilla::Plugin::MakeMaker> plugin and must appear in your dist.ini after
-that plugin.
+This plugin works for Makefile.PL generated by the L<Dist::Zilla::Plugin::MakeMaker>
+plugin or the Build.PL generated by the L<Dist::Zilla::Plugin::ModuleBuild> plugin,
+and must appear in your dist.ini after whichever you use.
 
 This plugin is a fairly gross hack, based on the technique used for
 L<Dist::Zilla::Plugin::DualLife> and might break ifE<sol>when Dist::Zilla
-changes how it generates a Makefile.PL.
+changes how it generates install scripts.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the issue tracker
+at L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-OSPrereqs>.
+You will be notified automatically of any progress on your issue.
+
+=head2 Source Code
+
+This is open source software.  The code repository is available for
+public review and contribution under the terms of the license.
+
+L<https://github.com/dagolden/dist-zilla-plugin-osprereqs>
+
+  git clone git://github.com/dagolden/dist-zilla-plugin-osprereqs.git
 
 =head1 AUTHOR
 
@@ -164,10 +203,3 @@ This is free software, licensed under:
   The Apache License, Version 2.0, January 2004
 
 =cut
-
-
-__END__
-
-__END__
-
-
